@@ -1,5 +1,5 @@
 
-from generallibrary import CodeLine, current_datetime, Markdown
+from generallibrary import CodeLine, Markdown, Date, flatten, exclusive
 from generalfile import Path
 
 
@@ -44,44 +44,54 @@ class _PackagerFiles:
         self.file_personal_readme = GenerateFile(self.localrepo.get_readme_path(), self.generate_personal_readme, self, aesthetic=True)
 
     def relative_path_is_aesthetic(self, relative_path):
-        """ Relative to package path. None if not defined as a GenerateFile instance.
+        """ Relative to package path. False if not defined as a GenerateFile instance.
 
             :param generalpackager.Packager self:
-            :param Path relative_path: """
+            :param Path or str relative_path: """
+        relative_path = Path(relative_path).relative(self.path)
         aesthetic_attr = getattr(self.files_by_relative_path.get(relative_path, None), "aesthetic", None)
         if aesthetic_attr is None:
             if relative_path.match(*self.extra_aesthetic):
                 return True
-            elif relative_path.match(*self.extra_non_aesthetic):
+            # elif relative_path.match(*self.extra_non_aesthetic):
+            #     return False
+            else:
                 return False
         return aesthetic_attr
 
-    def filter_relative_filenames(self, *filenames, aesthetic, non_defined=True):
+    def filter_relative_filenames(self, *filenames, aesthetic):
         """ If aesthetic is None then it doesn't filter any.
             True will return only aesthetic.
             False will return only non-aesthetic.
 
             :param generalpackager.Packager self:
-            :param bool or None aesthetic:
-            :param bool non_defined: """
-        result = []
-        for filename in filenames:
-            is_aesthetic = self.relative_path_is_aesthetic(filename)
-            if non_defined is False and is_aesthetic is None:
-                continue
-            if aesthetic is True and is_aesthetic is False:
-                continue
-            if aesthetic is False and is_aesthetic is True:
-                continue
-            result.append(filename)
-        return result
+            :param bool or None aesthetic: """
+        return [path for path in filenames if aesthetic is None or aesthetic is self.relative_path_is_aesthetic(path)]
 
-    def compare_local_to_remote(self, aesthetic=None):
+    def _compare_local(self, platform, aesthetic):
+        """ :param generalpackager.Packager self: """
+        unpack_target = Path.get_cache_dir() / "Python"
+        package_path = platform.download(path=unpack_target, overwrite=True)
+
+        filt = lambda path: not path.match(*self.git_exclude_lines)
+
+        differing_files = self.path.get_differing_files(target=package_path, filt=filt)
+
+        return self.filter_relative_filenames(*differing_files, aesthetic=aesthetic)
+
+    def compare_local_to_github(self, aesthetic=None):
         """ Get a list of changed files compared to remote with optional aesthetic files.
 
             :param generalpackager.Packager self:
             :param aesthetic: """
-        return self.filter_relative_filenames(*self.localrepo.get_changed_files(), aesthetic=aesthetic)
+        return self._compare_local(platform=self.github, aesthetic=aesthetic)
+
+    def compare_local_to_pypi(self, aesthetic=None):
+        """ Get a list of changed files compared to pypi with optional aesthetic files.
+
+            :param generalpackager.Packager self:
+            :param aesthetic: """
+        return self._compare_local(platform=self.pypi, aesthetic=aesthetic)
 
     def generate_setup(self):
         """ Generate setup.py.
@@ -109,25 +119,25 @@ class _PackagerFiles:
         }
 
         top = CodeLine()
-        top.add(CodeLine("from setuptools import setup, find_namespace_packages", space_before=1))
-        top.add(CodeLine("from pathlib import Path", space_after=1))
+        top.add_node(CodeLine("from setuptools import setup, find_namespace_packages", space_before=1))
+        top.add_node(CodeLine("from pathlib import Path", space_after=1))
 
-        setup = top.add(CodeLine("setup("))
+        setup = top.add_node(CodeLine("setup("))
         for key, value in setup_kwargs.items():
             if isinstance(value, list) and value:
-                list_ = setup.add(CodeLine(f"{key}=["))
+                list_ = setup.add_node(CodeLine(f"{key}=["))
                 for item in value:
-                    list_.add(CodeLine(f"'{item}',"))
-                setup.add(CodeLine("],"))
+                    list_.add_node(CodeLine(f"'{item}',"))
+                setup.add_node(CodeLine("],"))
             elif isinstance(value, dict) and value:
-                dict_ = setup.add(CodeLine(f"{key}={{"))
+                dict_ = setup.add_node(CodeLine(f"{key}={{"))
                 for k, v in value.items():
-                    dict_.add(CodeLine(f"'{k}': {v},"))
-                setup.add(CodeLine("},"))
+                    dict_.add_node(CodeLine(f"'{k}': {v},"))
+                setup.add_node(CodeLine("},"))
             else:
-                setup.add(CodeLine(f"{key}={value},"))
+                setup.add_node(CodeLine(f"{key}={value},"))
 
-        top.add(CodeLine(")"))
+        top.add_node(CodeLine(")"))
 
         return top.text()
 
@@ -150,9 +160,9 @@ class _PackagerFiles:
         """ Generate LICENSE by using Packager.license.
 
             :param generalpackager.Packager self: """
-        text = Path(self.repos_path / f"generalpackager/generalpackager/licenses/{self.license}").text.read()
+        text = Path(self.localrepo.get_repos_path() / f"generalpackager/generalpackager/licenses/{self.license}").text.read()
         assert "$" in text
-        text = text.replace("$year", str(current_datetime().year))
+        text = text.replace("$year", str(Date.now().datetime.year))
         text = text.replace("$author", self.author)
         assert "$" not in text
 
@@ -165,12 +175,12 @@ class _PackagerFiles:
         workflow = CodeLine()
         workflow.indent_str = " " * 2
 
-        workflow.add("name: workflow")
-        workflow.add(self.get_triggers())
+        workflow.add_node("name: workflow")
+        workflow.add_node(self.get_triggers())
 
-        jobs = workflow.add("jobs:")
-        jobs.add(self.get_unittest_job())
-        jobs.add(self.get_sync_job())
+        jobs = workflow.add_node("jobs:")
+        jobs.add_node(self.get_unittest_job())
+        jobs.add_node(self.get_sync_job())
 
         return workflow.text()
 
@@ -194,12 +204,12 @@ class _PackagerFiles:
         self.get_attributes_markdown().set_parent(parent=markdown)
 
         # Todos
-        todos = self.get_todos()
+        todos = [exclusive(todo, "Package") for todo in self.get_todos()]
         if todos:
             Markdown(header=self._todo_header, parent=markdown).add_table_lines(*todos)
 
         # Table of contents - Configuration
-        self.configure_contents_markdown(markdown=contents)
+        self._configure_contents_markdown(markdown=contents)
 
         # Footnote
         self.get_footnote_markdown().set_parent(parent=markdown)
@@ -210,6 +220,8 @@ class _PackagerFiles:
         """ Generate personal readme markdown and overwrite README.md in local repo.
 
             :param generalpackager.Packager self: """
+        ordered_packagers = type(self)().get_ordered_packagers()
+
         # Description
         markdown = Markdown(header="ManderaGeneral").add_list_lines(
             "A collection of connected packages.",
@@ -218,7 +230,12 @@ class _PackagerFiles:
         )
 
         # Package information
-        self.get_information_markdown(*self.load_general_packagers().values()).set_parent(parent=markdown)
+        self.get_information_markdown(*ordered_packagers).set_parent(parent=markdown)
+
+        # Todos
+        todos = flatten([packager.get_todos() for packager in ordered_packagers])
+        if todos:
+            Markdown(header=self._todo_header, parent=markdown).add_table_lines(*todos)
 
         # Footnote
         self.get_footnote_markdown(commit=False).set_parent(parent=markdown)
