@@ -1,5 +1,5 @@
 
-from generallibrary import Markdown, current_datetime_formatted, floor
+from generallibrary import Markdown, floor, Date, deco_cache, ObjInfo
 from generalfile import Path
 
 import re
@@ -19,13 +19,20 @@ class _PackagerMarkdown:
             "Operating System": f"[![Generic badge](https://img.shields.io/badge/platforms-{'%20%7C%20'.join(self.os)}-blue.svg)](https://shields.io/)",
         }
 
-    def get_todos(self):
-        """ Get a list of dicts containing cleaned up todos.
 
-            :param generalpackager.Packager self:
-            :rtype: dict[list[str]] """
+    def _create_todo_dict(self, text, path, line):
+        """ :param generalpackager.Packager self: """
+        path = Path(path)
+        return {
+            "Package": Markdown.link(text=self.name, url=self.github.url),
+            "Module": self.github_link_path_line(text=path.name(), path=path, line=1),
+            "Message": self.github_link_path_line(text=text, path=path, line=line),
+        }
+
+    def _get_codeline_todos(self):
+        """ :param generalpackager.Packager self: """
         todos = []
-        for path in self.path.get_paths_recursive():
+        for path in self.path.get_children(depth=-1, gen=True):
             if path.match(*self.git_exclude_lines, "shelved.patch", "readme.md"):
                 continue
             try:
@@ -38,18 +45,33 @@ class _PackagerMarkdown:
             for i, line in enumerate(text.splitlines()):
                 result = re.findall("todo+: (.+)", line, re.I)
                 if result:
-                    todo = re.sub('[" ]*$', "", result[0])
-                    todos.append({
-                        "Module": self.github_link_path_line(text=path.name(), path=relative_path, line=1),
-                        "Message": self.github_link_path_line(text=todo, path=relative_path, line=i + 1),
-                    })
+                    text = re.sub('[" ]*$', "", result[0])
+                    todos.append(self._create_todo_dict(text=text, path=relative_path, line=i + 1))
         return todos
 
+    def _get_untested_todos(self):
+        """ :param generalpackager.Packager self: """
+        todos = []
+        for name, objInfo in self.get_untested_objInfo_dict().items():  # type: ObjInfo
+            text = f"Create unittest for '{name}'."
+            path = objInfo.file(relative=True)
+            line = objInfo.get_definition_line()
+            todos.append(self._create_todo_dict(text=text, path=path, line=line))
+        return todos
+
+    @deco_cache()
+    def get_todos(self):
+        """ Get a list of dicts containing cleaned up todos.
+
+            :param generalpackager.Packager self:
+            :rtype: dict[list[str]] """
+        return self._get_codeline_todos() + self._get_untested_todos()
+
     def get_description_markdown(self):
         """ Get information table.
 
             :param generalpackager.Packager self: """
-        part_of = f"This package and {len(self.packagers_dict) - 1} other make up {Markdown.link(text='ManderaGeneral', url='https://github.com/Mandera')}."
+        part_of = f"This package and {len(self.get_all()) - 1} other make up {Markdown.link(text='ManderaGeneral', url='https://github.com/Mandera')}."
 
         return Markdown(self.localrepo.description, "\n", part_of, header=self.name)
 
@@ -65,7 +87,7 @@ class _PackagerMarkdown:
 
         list_of_dicts = []
         for packager in packagers:
-            attrs = packager.localmodule.objInfo.get_all()
+            attrs = packager.localmodule.objInfo.get_children(depth=-1)
             tested_attrs = [objInfo for objInfo in attrs if packager.localrepo.text_in_tests(text=objInfo.name)]
             test_percentage = floor(len(tested_attrs) / len(attrs) * 100, 1)
 
@@ -75,8 +97,8 @@ class _PackagerMarkdown:
                 "Latest Release": packager.get_latest_release(),
                 "Python": ", ".join([Markdown.link(text=ver, url=f"{python_url}{str(ver).replace('.', '')}0/") for ver in packager.python]),
                 "Platform": ", ".join(map(str.capitalize, packager.os)),
-                "Todo": Markdown.link(text=len(packager.get_todos()), url=f"{packager.github.url}#{self._todo_header}"),
                 "Lvl": packager.get_ordered_index(),
+                "Todo": Markdown.link(text=len(packager.get_todos()), url=f"{packager.github.url}#{self._todo_header}"),
                 "Tests": f"{test_percentage} %",
             })
         markdown.add_table_lines(*list_of_dicts, sort_by=["Lvl", "Package"])
@@ -107,19 +129,21 @@ class _PackagerMarkdown:
 
         return markdown
 
-    def configure_contents_markdown(self, markdown):
+    def _configure_contents_markdown(self, markdown):
         """ Configure table of contents lines from markdown.
 
             :param generalpackager.Packager self:
             :param markdown: """
-        parent_markdown = markdown.get_parent(-1)
+        parent_markdown = markdown.get_parent(-1, -1)
         markdown.add_pre_lines(parent_markdown.view(custom_repr=lambda md: md.link(md.header, href=True), print_out=False))
         return markdown
 
     def github_link(self, text, suffix):
-        """ :param generalpackager.Packager self:
-            :param text:
-            :param suffix: """
+        """ Get an HREF link to this repo's github.
+
+            :param generalpackager.Packager self:
+            :param text: Text to be clickable.
+            :param suffix: URL suffix. """
         url = f"{self.github.url}/{suffix}"
         return Markdown.link(text=text, url=url, href=True)
 
@@ -138,12 +162,13 @@ class _PackagerMarkdown:
 
             :param generalpackager.Packager self:
             :param generallibrary.ObjInfo objInfo: """
-        text = objInfo.nice_repr()
+        text = repr(objInfo)
         path = objInfo.file(relative=True)
         line = objInfo.get_definition_line()
 
         string = self.github_link_path_line(text=text, path=path, line=line)
-        if not self.localrepo.text_in_tests(text=objInfo.name):
+
+        if objInfo.name in self.get_untested_objInfo_dict():
             string = f"{string} <b>(Untested)</b>"
 
         return string
@@ -160,7 +185,7 @@ class _PackagerMarkdown:
 
             :param generalpackager.Packager self:
             :param commit: """
-        line = f"Generated {current_datetime_formatted()}"
+        line = f"Generated {Date.now()}"
         if commit:
             line += f" for commit {self.github_link(text=self.commit_sha, suffix=f'commit/{self.commit_sha}')}."
 
